
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) 
[![Build Status - GitHub](https://github.com/isDynamics/EdiHeadyTrack/workflows/pytesting/badge.svg)](https://github.com/isDynamics/EdiHeadyTrack/actions/workflows/pytesting.yml)
[![codecov](https://codecov.io/gh/isDynamics/EdiHeadyTrack/branch/master/graph/badge.svg?token=FOE3NBS07X)](https://codecov.io/gh/isDynamics/EdiHeadyTrack)
[![Documentation Status](https://readthedocs.org/projects/ediheadytrack/badge/?version=latest)](https://ediheadytrack.readthedocs.io/en/latest/?badge=latest)
# EdiHeadyTrack

## Contributors 

<a href="https://github.com/isDynamics/EdiHeadyTrack/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=isDynamics/EdiHeadyTrack" />
</a>

Made with [contrib.rocks](https://contrib.rocks).

<!-- ## Table of contents
- [EdiHeadyTrack](#ediheadytrack)
  - [Table of contents](#table-of-contents)
  - [About](#about)
  - [Technologies](#technologies)
  - [Setup](#setup)
  - [Citation](#citation)
  - [To do](#to-do)
  - [Getting Involved](#getting-involved)
  - [Citations](#citations) -->

## About
EdiHeadyTrack is a Python package for measuring head kinematics using markerless head pose detection methods. The current implementation primarily uses the FaceMesh module of MediaPipe's Python API for facial landmark detection alongside OpenCV for handling simple computer vision tasks.

Full documentation for EdiHeadyTrack can be found [here](https://ediheadytrack.readthedocs.io).


## Technologies
Project is created with:
* Python 3.9.0
	
## Setup
EdiHeadyTrack is available on PyPI! Install using:
```bash
pip install EdiHeadyTrack
```
For further installation instructions, consult the [documentation](https://ediheadytrack.readthedocs.io/en/latest/installation.html).

## Example
An example output from EdiHeadyTrack is shown below. A full worked example detailing how this can be achieved is provided [here](https://ediheadytrack.readthedocs.io/en/latest/example.html). 
![Example image](https://raw.githubusercontent.com/isDynamics/EdiHeadyTrack/master/EdiHeadyTrack/resources/comparison.png)


<!-- ## Change log
See [CHANGELOG.md](https://github.com/isDynamics/EdiHeadyTrack/blob/master/CHANGELOG.md).


## Contributing
See [CONTRIBUTING.md](https://github.com/isDynamics/EdiHeadyTrack/blob/master/CONTRIBUTING.md). -->


## Citation
If you use `EdiHeadyTrack` in you work, please cite the following publication:

<!-- > S. Heldens, A. Sclocco, H. Dreuning, B. van Werkhoven, P. Hijma, J. Maassen & R.V. van Nieuwpoort (2022), "litstudy: A Python package for literature reviews", SoftwareX 20 -->


As BibTeX:

<!-- ```
@article{litstudy,
    title = {litstudy: A Python package for literature reviews},
    journal = {SoftwareX},
    volume = {20},
    pages = {101207},
    year = {2022},
    issn = {2352-7110},
    doi = {https://doi.org/10.1016/j.softx.2022.101207},
    url = {https://www.sciencedirect.com/science/article/pii/S235271102200125X},
    author = {S. Heldens and A. Sclocco and H. Dreuning and B. {van Werkhoven} and P. Hijma and J. Maassen and R. V. {van Nieuwpoort}},
}
``` -->

## Getting Involved
For any suggestions, please [create a new issue](https://github.com/isDynamics/EdiHeadyTrack/issues).

<!-- ## Citations -->
<!-- 1. Teixeira-Dias, F. (1995). *Numerical simulation of tensile and shear tests in plane strain and plane stress* (Doctoral dissertation)
2. Teixeira-Dias, F. and Menezes, L.F. (2001), *Numerical aspects of finite element simulations of residual stresses in metal matrix composites*. Int. J. Numer. Meth. Engng., 50: 629-644.


[1]: https://www.researchgate.net/publication/237021517_Numerical_simulation_of_tensile_and_shear_tests_in_plane_strain_and_plane_stress
[2]: https://doi.org/10.1002/1097-0207(20010130)50:3<629::AID-NME41>3.0.CO;2-7 -->


